import * as commonjsHelpers from "_commonjsHelpers.js";
import { __exports as input } from "\u0000fixtures/form/ignore-ids/input.js?commonjs-exports";
import require$$0 from "\u0000CWD/fixtures/form/ignore-ids/bar.js?commonjs-proxy";

var foo = require( 'foo' );
var bar = require$$0;

export { input as __moduleExports, input as default };
